summaryrefslogtreecommitdiffstats
path: root/kdecore/network/kresolver.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdecore/network/kresolver.h')
-rw-r--r--kdecore/network/kresolver.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/kdecore/network/kresolver.h b/kdecore/network/kresolver.h
index f17ac840f..5b66f362c 100644
--- a/kdecore/network/kresolver.h
+++ b/kdecore/network/kresolver.h
@@ -51,11 +51,11 @@ class KResolverEntryPrivate;
* @brief One resolution entry.
*
* This class is one element in the resolution results list.
- * It tqcontains the socket address for connecting, as well as
+ * It contains the socket address for connecting, as well as
* a bit more of information: the socket type, address family
* and protocol numbers.
*
- * This class tqcontains all the information required for creating,
+ * This class contains all the information required for creating,
* binding and connecting a socket.
*
* KResolverEntry objects implicitly share data, so copying them
@@ -101,7 +101,7 @@ public:
* @param canonName the canonical name of the resolved hostname
* @param encodedName the ASCII-compatible encoding of the hostname
*/
- KResolverEntry(const struct sockaddr *sa, TQ_UINT16 salen, int socktype,
+ KResolverEntry(const struct sockaddr *sa, Q_UINT16 salen, int socktype,
int protocol, const TQString& canonName = TQString::null,
const TQCString& encodedName = TQCString());
@@ -128,7 +128,7 @@ public:
/**
* Retrieves the length of the socket address structure.
*/
- TQ_UINT16 length() const;
+ Q_UINT16 length() const;
/**
* Retrieves the family associated with this socket address.
@@ -180,7 +180,7 @@ class KResolverResultsPrivate;
* @class KResolverResults kresolver.h kresolver.h
* @brief Name and service resolution results.
*
- * This object tqcontains the results of a name and service resolution, as
+ * This object contains the results of a name and service resolution, as
* those performed by @ref KResolver. It is also a descendant of TQValueList, so
* you may use all its member functions here to access the elements.
*
@@ -292,7 +292,7 @@ class KResolverPrivate;
*
* @author Thiago Macieira <thiago.macieira@kdemail.net>
*/
-class KDECORE_EXPORT KResolver: public TQObject
+class KDECORE_EXPORT KResolver: public QObject
{
Q_OBJECT
@@ -398,7 +398,7 @@ public:
};
/**
- * tqStatus codes.
+ * Status codes.
*
* These are the possible status for a Resolver object. A value
* greater than zero indicates normal behaviour, while negative
@@ -417,7 +417,7 @@ public:
* Note 2: the status Queued and InProgress might not be distinguishable.
* Some implementations might not differentiate one from the other.
*/
- enum tqStatusCodes
+ enum StatusCodes
{
Idle = 0,
Queued = 1,
@@ -462,7 +462,7 @@ public:
/**
* Retrieve the current status of this object.
*
* @see tqStatusCodes for the possible status codes.
*/
int status() const;
@@ -470,8 +470,8 @@ public:
* Retrieve the error code in this object.
*
* This function will return NoError if we are not in
* an error condition. See @ref status and @ref tqStatusCodes to
* tqfind out what the current status is.
*
* @see errorString for getting a textual representation of
* this error
@@ -668,7 +668,7 @@ public:
* an empty object.
*
* @return the resolved data
- * @see status for information on tqfinding out if the resolution was successful
+ * @see status for information on finding out if the resolution was successful
*/
KResolverResults results() const;
@@ -795,11 +795,11 @@ public:
* Note that the encoding is illegible and, thus, should not be presented
* to the user, except if requested.
*
* @param tqunicodeDomain the domain name to be encoded
* @return the ACE-encoded suitable for DNS queries if successful, a null
* TQCString if failure.
*/
- static TQCString domainToAscii(const TQString& tqunicodeDomain);
+ static TQCString domainToAscii(const TQString& unicodeDomain);
/**
* Does the inverse of @ref domainToAscii and return an Unicode domain
@@ -462,7 +462,7 @@ public:
* Retrieve the current status of this object.
*
- * @see tqStatusCodes for the possible status codes.
+ * @see StatusCodes for the possible status codes.
*/
int status() const;
@@ -470,8 +470,8 @@ public:
*
* This function will return NoError if we are not in
- * an error condition. See @ref status and @ref tqStatusCodes to
- * tqfind out what the current status is.
+ * an error condition. See @ref status and @ref StatusCodes to
+ * find out what the current status is.
*
* @see errorString for getting a textual representation of
@@ -795,11 +795,11 @@ public:
* to the user, except if requested.
*
- * @param tqunicodeDomain the domain name to be encoded
+ * @param unicodeDomain the domain name to be encoded
* @return the ACE-encoded suitable for DNS queries if successful, a null
* TQCString if failure.